#!/bin/sh
# This small script tries to configure Plesk-specific
# wrapper (mm_wrapper) which ensures that 
# /usr/lib/mailman/mail/mailman will be called with
# the correct group.
# The problem is that on RH* and derivatives
# /usr/lib/mailman/mail/mailman should be called
# from within a process with one of the following groups:
# mail, nobody, postfix, daemon
# while on SuSE this should be a group whose gid is
# stored in either /etc/mailman/mailman.mail-gid or
# /etc/mailman/mailman.cgi-gid.
# So if the file /etc/mailman/mailman.mail-gid exist
# we ensure that it contains an appropriate gid and
# change the file if needed (preserving a backup)
# If the file is missing then we make sure that
# mm_wrapper is SGID mail.
#
# Requirements: coreutils, grep, sed, perl

# Some constant setup

# Some raw shells (ash, dash) don't have support for explicit variable
# declarations
#declare mm_wrapper initial_group gidfile

mm_wrapper=/var/qmail/bin/mm_wrapper
initial_group=popuser
gidfiles="/etc/mailman/mailman.mail-gid /etc/mailman.mail-gid"
backup=.saved_by_psa

# Same for fancy functions declarations
#function die()
die()
    { echo "$@" >&2; exit 1; }

# 1st check if the mm_wrapper is SGID
#function isSGID() {
isSGID() {
    # Does it really work? ;-)
    ! perl -e "exit(-g \"$1\");"
}

# stat has different options in Linux and in
# other supported systems
if [ x$(uname -s) = xLinux ]; then
#    function getFGID()
    getFGID()
        { stat -c%g "$1"; }
else
#    function getFGID()
    getFGID()
        { stat -f '%g' "$1"; }
fi

# hack! hack! hack!
#function getGNam()
getGNam()
    { grep "^$1:" /etc/group | cut -f 3 -d ':'; }

#declare mm_wrapper_group 

if isSGID "$mm_wrapper" ; then
    mm_wrapper_group=$(getFGID "$mm_wrapper")
else
    mm_wrapper_group=$(getGNam "$initial_group")
fi

[ -z "$mm_wrapper_group" ] && die "unable to get current mm_wrapper group"

# Now check the style of operation
hasGidfile=0;
for gidfile in $gidfiles; do
    if [ -r "$gidfile" ]; then
        if [ x$(cat "$gidfile") != x$mm_wrapper_group ]; then
	    cp -pr "$gidfile" "$gidfile$backup" || die "Unable to create a backup file";
	    echo -n "$mm_wrapper_group" > "$gidfile";
        fi;
	hasGidfile=1;
    fi;
done;

if [ $hasGidfile = 0 ]; then
    # need to "hardcode" the SGID group
    chown :mail "$mm_wrapper"
    chmod g+s "$mm_wrapper"
fi

